You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@age.apache.org by jg...@apache.org on 2023/01/03 16:57:18 UTC

[age] branch master updated: Fixed typos at multiple locations (#470)

This is an automated email from the ASF dual-hosted git repository.

jgemignani pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/age.git


The following commit(s) were added to refs/heads/master by this push:
     new 9bc3607  Fixed typos at multiple locations (#470)
9bc3607 is described below

commit 9bc36072819084377aecea48a89d108eddb368ef
Author: Umar Hayat <m....@gmail.com>
AuthorDate: Wed Jan 4 01:57:13 2023 +0900

    Fixed typos at multiple locations (#470)
---
 README.md                                          |  2 +-
 drivers/golang/README.md                           |  2 +-
 drivers/golang/parser/Age.g4                       |  2 +-
 drivers/golang/parser/README.md                    |  2 +-
 drivers/golang/samples/main.go                     |  2 +-
 drivers/golang/samples/sql_api_sample.go           |  4 ++--
 drivers/jdbc/README.md                             |  2 +-
 .../org/apache/age/jdbc/AgtypeStatementTest.java   | 12 +++++-----
 drivers/python/README.md                           |  2 +-
 drivers/python/age/exceptions.py                   |  2 +-
 drivers/python/antlr/README.md                     |  2 +-
 drivers/python/samples/apache-age-note.ipynb       |  2 +-
 regress/expected/cypher_create.out                 |  2 +-
 regress/sql/cypher_create.sql                      |  2 +-
 src/backend/executor/cypher_delete.c               |  2 +-
 src/backend/executor/cypher_merge.c                | 10 ++++-----
 src/backend/executor/cypher_set.c                  |  4 ++--
 src/backend/parser/cypher_analyze.c                |  2 +-
 src/backend/parser/cypher_clause.c                 | 26 +++++++++++-----------
 src/backend/utils/adt/age_session_info.c           |  2 +-
 src/backend/utils/adt/age_vle.c                    | 16 ++++++-------
 src/backend/utils/name_validation.c                |  2 +-
 src/include/executor/cypher_utils.h                |  2 +-
 src/include/nodes/cypher_nodes.h                   |  6 ++---
 src/include/nodes/cypher_readfuncs.h               |  2 +-
 src/include/parser/cypher_transform_entity.h       |  4 ++--
 src/include/utils/load/csv.h                       |  4 ++--
 27 files changed, 61 insertions(+), 61 deletions(-)

diff --git a/README.md b/README.md
index a57f855..e51068c 100644
--- a/README.md
+++ b/README.md
@@ -145,7 +145,7 @@ sudo apt install postgresql
 &nbsp;Install From Source Code
 </h4>
 
-You can <a href="https://www.postgresql.org/ftp/source/"> download the Postgres </a> source code and install your own instance of Postgres. You can read instructions on how to install from source code for different versions on the <a href="https://www.postgresql.org/docs/11/installation.html">offical Postgres Website.</a>
+You can <a href="https://www.postgresql.org/ftp/source/"> download the Postgres </a> source code and install your own instance of Postgres. You can read instructions on how to install from source code for different versions on the <a href="https://www.postgresql.org/docs/11/installation.html">official Postgres Website.</a>
 
 
 
diff --git a/drivers/golang/README.md b/drivers/golang/README.md
index 4433212..3670310 100644
--- a/drivers/golang/README.md
+++ b/drivers/golang/README.md
@@ -1,6 +1,6 @@
 # age AGType parser and driver support for Golang 
 
-AGType parser and driver support for [Apache AGE](https://age.apache.org/), graph extention for PostgreSQL.
+AGType parser and driver support for [Apache AGE](https://age.apache.org/), graph extension for PostgreSQL.
 
 ### Features
 * Unmarshal AGE result data(AGType) to Vertex, Edge, Path
diff --git a/drivers/golang/parser/Age.g4 b/drivers/golang/parser/Age.g4
index c5516a9..96ac4e6 100644
--- a/drivers/golang/parser/Age.g4
+++ b/drivers/golang/parser/Age.g4
@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-/* Apache AGE output data grammer */
+/* Apache AGE output data grammar */
 grammar Age;
 
 ageout
diff --git a/drivers/golang/parser/README.md b/drivers/golang/parser/README.md
index 6319ce7..a70eede 100644
--- a/drivers/golang/parser/README.md
+++ b/drivers/golang/parser/README.md
@@ -1,5 +1,5 @@
 # ANTLR4 Go Query Result data parser generation rules for apache-age-go
-Go driver for Apache AGE, graph extention for PostgreSQL.
+Go driver for Apache AGE, graph extension for PostgreSQL.
 
 
 ### Build
diff --git a/drivers/golang/samples/main.go b/drivers/golang/samples/main.go
index 9839e55..f2e349d 100644
--- a/drivers/golang/samples/main.go
+++ b/drivers/golang/samples/main.go
@@ -32,7 +32,7 @@ var graphName string = "testGraph"
 
 func main() {
 
-	// Do cypher query to AGE with database/sql Tx API transaction conrol
+	// Do cypher query to AGE with database/sql Tx API transaction control
 	fmt.Println("# Do cypher query with SQL API")
 	doWithSqlAPI(dsn, graphName)
 
diff --git a/drivers/golang/samples/sql_api_sample.go b/drivers/golang/samples/sql_api_sample.go
index 491532f..9e67e09 100644
--- a/drivers/golang/samples/sql_api_sample.go
+++ b/drivers/golang/samples/sql_api_sample.go
@@ -25,7 +25,7 @@ import (
 	"github.com/apache/age/drivers/golang/age"
 )
 
-// Do cypher query to AGE with database/sql Tx API transaction conrol
+// Do cypher query to AGE with database/sql Tx API transaction control
 func doWithSqlAPI(dsn string, graphName string) {
 
 	// Connect to PostgreSQL
@@ -75,7 +75,7 @@ func doWithSqlAPI(dsn string, graphName string) {
 	if err != nil {
 		panic(err)
 	}
-	// Unmarsal result data to Vertex row by row
+	// Unmarshal result data to Vertex row by row
 	for cypherCursor.Next() {
 		row, err := cypherCursor.GetRow()
 		if err != nil {
diff --git a/drivers/jdbc/README.md b/drivers/jdbc/README.md
index c04529e..d223730 100644
--- a/drivers/jdbc/README.md
+++ b/drivers/jdbc/README.md
@@ -1,6 +1,6 @@
 # **AGE AGType parser and driver support for Java**
 
-AGType parser and driver support forĀ [Apache AGE](https://age.apache.org/), graph extention for PostgreSQL.
+AGType parser and driver support forĀ [Apache AGE](https://age.apache.org/), graph extension for PostgreSQL.
 
 ## Prerequisites
 
diff --git a/drivers/jdbc/lib/src/test/java/org/apache/age/jdbc/AgtypeStatementTest.java b/drivers/jdbc/lib/src/test/java/org/apache/age/jdbc/AgtypeStatementTest.java
index e13e5bb..e160ef3 100644
--- a/drivers/jdbc/lib/src/test/java/org/apache/age/jdbc/AgtypeStatementTest.java
+++ b/drivers/jdbc/lib/src/test/java/org/apache/age/jdbc/AgtypeStatementTest.java
@@ -56,7 +56,7 @@ class AgtypeStatementTest {
     /**
      * When a statement is run first, "ag_catalog"."agtype" needs to be added to the connection.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void agTypeInStatementAsString() throws SQLException, InvalidAgtypeException {
@@ -69,7 +69,7 @@ class AgtypeStatementTest {
      * When a Prepared statement is run first and the agtype is a parameter, agtype needs to be
      * added to the connection.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void asTypeInPreparedStatementAsParameter() throws SQLException, InvalidAgtypeException {
@@ -82,7 +82,7 @@ class AgtypeStatementTest {
      * When a Prepared statement is run first and the agtype is not a parameter, but in the string,
      * "ag_catalog"."agtype" needs to be added to the connection.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void asTypeInPreparedStatementAsString() throws SQLException, InvalidAgtypeException {
@@ -95,7 +95,7 @@ class AgtypeStatementTest {
      * When a Prepared statement is run and agType is both a string and a parameter, agtype needs to
      * be added to the connection, but "ag_catalog."agtype" does not need to be added.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void agTypeInPreparedStatementAsStringAndParam() throws SQLException, InvalidAgtypeException {
@@ -111,7 +111,7 @@ class AgtypeStatementTest {
      * When a statement is run first, "ag_catalog"."agType" needs to be added to the connection, no
      * need to add agtype for running a Prepared Statement afterward.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void asTypeInStatementThenPreparedStatement() throws SQLException, InvalidAgtypeException {
@@ -126,7 +126,7 @@ class AgtypeStatementTest {
      * When a Prepared statement is run first, agtype needs to be added to the connection, no need
      * to add "ag_catalog"."agType" for running a Statement afterward.
      *
-     * @throws SQLException Throws an SQL Exepction if the driver is unable to parse Agtype.
+     * @throws SQLException Throws an SQL Exception if the driver is unable to parse Agtype.
      */
     @Test
     void asTypeInPreparedStatementThenStatement() throws SQLException, InvalidAgtypeException {
diff --git a/drivers/python/README.md b/drivers/python/README.md
index ab75732..af1705e 100644
--- a/drivers/python/README.md
+++ b/drivers/python/README.md
@@ -1,5 +1,5 @@
 # AGE AGType parser and driver support for Python
-AGType parser and driver support for [Apache AGE](https://age.apache.org/), graph extention for PostgreSQL.
+AGType parser and driver support for [Apache AGE](https://age.apache.org/), graph extension for PostgreSQL.
 
 ### Features
 * Unmarshal AGE result data(AGType) to Vertex, Edge, Path
diff --git a/drivers/python/age/exceptions.py b/drivers/python/age/exceptions.py
index 7bbb5b4..cee9cc3 100644
--- a/drivers/python/age/exceptions.py
+++ b/drivers/python/age/exceptions.py
@@ -59,7 +59,7 @@ class SqlExecutionError(Exception):
         super().__init__(msg, cause)
     
     def __repr__(self) :
-        return 'SqlExcution [' + self.msg + ']'  
+        return 'SqlExecution [' + self.msg + ']'  
 
 class AGTypeError(Exception):
     def __init__(self, msg, cause):
diff --git a/drivers/python/antlr/README.md b/drivers/python/antlr/README.md
index b83b17d..bd817ad 100644
--- a/drivers/python/antlr/README.md
+++ b/drivers/python/antlr/README.md
@@ -1,5 +1,5 @@
 # ANTLR4 Python3 Agtype parser generation rules for apache-age 
-Python driver for Apache AGE, graph extention for PostgreSQL.
+Python driver for Apache AGE, graph extension for PostgreSQL.
 
 
 ### Build
diff --git a/drivers/python/samples/apache-age-note.ipynb b/drivers/python/samples/apache-age-note.ipynb
index c63ec9f..44b15b4 100644
--- a/drivers/python/samples/apache-age-note.ipynb
+++ b/drivers/python/samples/apache-age-note.ipynb
@@ -11,7 +11,7 @@
     "```\n",
     "import age\n",
     "```\n",
-    "## Connect to PostgreSQL(with AGE extention)\n",
+    "## Connect to PostgreSQL(with AGE extension)\n",
     "* Connect to PostgreSQL server \n",
     "* Load AGE and register agtype to db session (Psycopg2 driver)\n",
     "* Check graph exists and set graph. If not, age make that.\n",
diff --git a/regress/expected/cypher_create.out b/regress/expected/cypher_create.out
index fb92a37..7cac75e 100644
--- a/regress/expected/cypher_create.out
+++ b/regress/expected/cypher_create.out
@@ -324,7 +324,7 @@ $$) as (a agtype, b agtype);
 SELECT * FROM cypher('cypher_create', $$
 	MATCH (a:n_var)
 	WHERE a.name = 'Node Z'
-	CREATE (a)-[:e_var {name: a.name + ' -> doesnt exist'}]->(:n_other_node)
+	CREATE (a)-[:e_var {name: a.name + ' -> does not exist'}]->(:n_other_node)
 	RETURN a
 $$) as (a agtype);
  a 
diff --git a/regress/sql/cypher_create.sql b/regress/sql/cypher_create.sql
index 62b7d16..5934dcb 100644
--- a/regress/sql/cypher_create.sql
+++ b/regress/sql/cypher_create.sql
@@ -172,7 +172,7 @@ $$) as (a agtype, b agtype);
 SELECT * FROM cypher('cypher_create', $$
 	MATCH (a:n_var)
 	WHERE a.name = 'Node Z'
-	CREATE (a)-[:e_var {name: a.name + ' -> doesnt exist'}]->(:n_other_node)
+	CREATE (a)-[:e_var {name: a.name + ' -> does not exist'}]->(:n_other_node)
 	RETURN a
 $$) as (a agtype);
 
diff --git a/src/backend/executor/cypher_delete.c b/src/backend/executor/cypher_delete.c
index 3d9406b..9344a86 100644
--- a/src/backend/executor/cypher_delete.c
+++ b/src/backend/executor/cypher_delete.c
@@ -77,7 +77,7 @@ const CustomExecMethods cypher_delete_exec_methods = {DELETE_SCAN_STATE_NAME,
 
 /*
  * Initialization at the beginning of execution. Setup the child node,
- * setup its scan tuple slot and projection infp, expression context,
+ * setup its scan tuple slot and projection info, expression context,
  * collect metadata about visible edges, and alter the commandid for
  * the transaction.
  */
diff --git a/src/backend/executor/cypher_merge.c b/src/backend/executor/cypher_merge.c
index c65abf2..2502c97 100644
--- a/src/backend/executor/cypher_merge.c
+++ b/src/backend/executor/cypher_merge.c
@@ -114,7 +114,7 @@ static void begin_cypher_merge(CustomScanState *node, EState *estate,
         Relation rel;
 
         /*
-         * This entity is refrences an entity that is already declared. Either
+         * This entity is references an entity that is already declared. Either
          * by a previous clause or an entity earlier in the MERGE path. In both
          * cases, this target_entry will not create data, only reference data
          * that already exists.
@@ -124,7 +124,7 @@ static void begin_cypher_merge(CustomScanState *node, EState *estate,
             continue;
         }
 
-        // Open relation and aquire a row exclusive lock.
+        // Open relation and acquire a row exclusive lock.
         rel = heap_open(cypher_node->relid, RowExclusiveLock);
 
         // Initialize resultRelInfo for the vertex
@@ -189,7 +189,7 @@ static bool check_path(cypher_merge_custom_scan_state *css,
          * If target_node as a valid attribute number and is a node not
          * declared in a previous clause, check the tuple position in the
          * slot. If the slot is null, the path was not found. The rules
-         * state that if one part of the path does not exists, the whold
+         * state that if one part of the path does not exists, the whole
          * path must be created.
          */
         if (node->tuple_position != InvalidAttrNumber ||
@@ -477,7 +477,7 @@ static TupleTableSlot *exec_cypher_merge(CustomScanState *node)
             Assert(css->found_a_path == false);
 
             /*
-             * This block of sub-case 1 should only be exectuted once. To
+             * This block of sub-case 1 should only be executued once. To
              * create the single path if the path does not exist. If we find
              * ourselves here again, the internal state of the MERGE execution
              * node was incorrectly altered.
@@ -513,7 +513,7 @@ static TupleTableSlot *exec_cypher_merge(CustomScanState *node)
                                 econtext->ecxt_scantuple->tts_values,
                                 econtext->ecxt_scantuple->tts_isnull);
 
-            // store the heap tuble
+            // store the heap tuple
             ExecStoreTuple(heap_tuple, econtext->ecxt_scantuple, InvalidBuffer, false);
 
             /*
diff --git a/src/backend/executor/cypher_set.c b/src/backend/executor/cypher_set.c
index 1bc74b7..8baea71 100644
--- a/src/backend/executor/cypher_set.c
+++ b/src/backend/executor/cypher_set.c
@@ -211,7 +211,7 @@ static bool check_path(agtype_value *path, graphid updated_id)
 
 /*
  * Construct a new agtype path with the entity with updated_id
- * replacing all of its intances in path with updated_entity
+ * replacing all of its instances in path with updated_entity
  */
 static agtype_value *replace_entity_in_path(agtype_value *path,
                                             graphid updated_id,
@@ -441,7 +441,7 @@ static void process_update_list(CustomScanState *node)
 
         /*
          * If we need to remove the property, set the value to NULL. Otherwise
-         * fetch the evaluated expression from the tuble slot.
+         * fetch the evaluated expression from the tuple slot.
          */
         if (remove_property)
         {
diff --git a/src/backend/parser/cypher_analyze.c b/src/backend/parser/cypher_analyze.c
index 685c7cb..b99ff0a 100644
--- a/src/backend/parser/cypher_analyze.c
+++ b/src/backend/parser/cypher_analyze.c
@@ -777,7 +777,7 @@ static Query *analyze_cypher_and_coerce(List *stmt, RangeTblFunction *rtfunc,
 
             /*
              * The coercion context of this coercion is COERCION_EXPLICIT
-             * because the target type is explicitly metioned in the column
+             * because the target type is explicitly mentioned in the column
              * definition list and we need to do this by looking up all
              * possible coercion.
              */
diff --git a/src/backend/parser/cypher_clause.c b/src/backend/parser/cypher_clause.c
index 8256287..9b0c76e 100644
--- a/src/backend/parser/cypher_clause.c
+++ b/src/backend/parser/cypher_clause.c
@@ -1671,7 +1671,7 @@ cypher_update_information *transform_cypher_set_item_list(
         {
             ereport(ERROR,
                     (errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
-                     errmsg("SET clause doesnt not support updating maps or lists in a property"),
+                     errmsg("SET clause does not support updating maps or lists in a property"),
                      parser_errposition(pstate, set_item->location)));
         }
 
@@ -3236,7 +3236,7 @@ static Node *make_type_cast_to_agtype(Node *arg)
 
 /*
  * Makes an agtype bool node that Postgres' transform expression logic
- * can handle. Used when contructed the join quals for building the paths
+ * can handle. Used when constructed the join quals for building the paths
  */
 static Node *make_bool_a_const(bool state)
 {
@@ -3343,7 +3343,7 @@ static List *join_to_entity(cypher_parsestate *cpstate,
     return quals;
 }
 
-// makes the quals neccessary when an edge is joining to another edge.
+// makes the quals necessary when an edge is joining to another edge.
 static List *make_edge_quals(cypher_parsestate *cpstate,
                              transform_entity *edge,
                              enum transform_entity_join_side side)
@@ -3434,7 +3434,7 @@ static A_Expr *filter_vertices_on_label_id(cypher_parsestate *cpstate,
 
 /*
  * Creates the Contains operator to process property contraints for a vertex/
- * edge in a MATCH clause. creates the agtype @> with the enitity's properties
+ * edge in a MATCH clause. creates the agtype @> with the entity's properties
  * on the right and the contraints in the MATCH clause on the left.
  */
 static Node *create_property_constraints(cypher_parsestate *cpstate,
@@ -3869,7 +3869,7 @@ static List *transform_match_entities(cypher_parsestate *cpstate, Query *query,
 /*
  * Iterate through the list of entities setup the join conditions. Joins
  * are driven through edges. To correctly setup the joins, we must
- * aquire information about the previous edge and vertex, and the next
+ * acquire information about the previous edge and vertex, and the next
  * edge and vertex.
  */
 static List *make_path_join_quals(cypher_parsestate *cpstate, List *entities)
@@ -4611,7 +4611,7 @@ transform_cypher_create_path(cypher_parsestate *cpstate, List **target_list,
         else
         {
             ereport(ERROR,
-                    (errmsg_internal("unreconized node in create pattern")));
+                    (errmsg_internal("unrecognized node in create pattern")));
         }
     }
 
@@ -4896,7 +4896,7 @@ static cypher_target_node *transform_create_cypher_existing_node(
      */
     if (declared_in_current_clause)
     {
-        rel->flags |= EXISTING_VARAIBLE_DECLARED_SAME_CLAUSE;
+        rel->flags |= EXISTING_VARIABLE_DECLARED_SAME_CLAUSE;
     }
 
     /*
@@ -5066,7 +5066,7 @@ static Expr *cypher_create_properties(cypher_parsestate *cpstate,
     }
     else
     {
-        ereport(ERROR, (errmsg_internal("unreconized entity type")));
+        ereport(ERROR, (errmsg_internal("unrecognized entity type")));
     }
 
     // add a volatile wrapper call to prevent the optimizer from removing it
@@ -5237,7 +5237,7 @@ static TargetEntry *findTarget(List *targetList, char *resname)
 }
 
 /*
- * Wrap the expression with a volatile function, to prevent the optimer from
+ * Wrap the expression with a volatile function, to prevent the optimizer from
  * elimating the expression.
  */
 static Expr *add_volatile_wrapper(Expr *node)
@@ -5308,7 +5308,7 @@ Query *cypher_parse_sub_analyze(Node *parseTree,
  * take:
  *
  * 1. If there is no previous clause, the query will have a subquery that
- * represents the path as a select staement, similar to match with a targetList
+ * represents the path as a select statement, similar to match with a targetList
  * that is all declared variables and the FuncExpr that represents the MERGE
  * clause with its needed metadata information, that will be caught in the
  * planner phase and converted into a path.
@@ -5445,7 +5445,7 @@ static Query *transform_cypher_merge(cypher_parsestate *cpstate,
  * This function does the heavy lifting of transforming a MERGE clause that has
  * a clause before it in the query of turning that into a lateral left join.
  * The previous clause will still be able to emit tuples if the path defined in
- * MERGE clause is not found. In that case variable assinged in the MERGE
+ * MERGE clause is not found. In that case variable assigned in the MERGE
  * clause will be emitted as NULL (same as OPTIONAL MATCH).
  */
 static cypher_create_path *
@@ -5658,7 +5658,7 @@ transform_cypher_merge_path(cypher_parsestate *cpstate, List **target_list,
         else
         {
             ereport(ERROR,
-                    (errmsg_internal("unreconized node in create pattern")));
+                    (errmsg_internal("unrecognized node in create pattern")));
         }
     }
 
@@ -5902,7 +5902,7 @@ static cypher_clause *convert_merge_to_match(cypher_merge *merge)
 }
 
 /*
- * Creates a namespace item for the given rte. boolean arguements will
+ * Creates a namespace item for the given rte. boolean arguments will
  * let the rest of the ParseState know if the relation and/or columns are
  * visible, whether the rte is only usable in lateral joins, and if the rte
  * is accessible in lateral joins.
diff --git a/src/backend/utils/adt/age_session_info.c b/src/backend/utils/adt/age_session_info.c
index 193aaa1..350273e 100644
--- a/src/backend/utils/adt/age_session_info.c
+++ b/src/backend/utils/adt/age_session_info.c
@@ -107,7 +107,7 @@ char *get_session_info_cypher_statement(void)
 /* function to return the state of the session info data */
 bool is_session_info_prepared(void)
 {
-    /* is the session infor prepared AND is the pid the same pid */
+    /* is the session info prepared AND is the pid the same pid */
     if (session_info_prepared == true &&
         session_info_pid == getpid())
     {
diff --git a/src/backend/utils/adt/age_vle.c b/src/backend/utils/adt/age_vle.c
index ad54bc9..f86a9e9 100644
--- a/src/backend/utils/adt/age_vle.c
+++ b/src/backend/utils/adt/age_vle.c
@@ -522,7 +522,7 @@ static VLE_local_context *build_local_vle_context(FunctionCallInfo fcinfo,
         /*
          * No context change is needed here as the cache entry is in the proper
          * context. Additionally, all of the modifications are either pointers
-         * to objects already in the proper context or primative types that will
+         * to objects already in the proper context or primitive types that will
          * be stored in that context since the memory is allocated there.
          */
 
@@ -1324,7 +1324,7 @@ static VLE_path_container *create_VLE_path_container(int64 path_size)
     /* allocate the container */
     vpc = palloc0(container_size_bytes);
 
-    /* initialze the PG headers */
+    /* initialize the PG headers */
     SET_VARSIZE(vpc, container_size_bytes);
 
     /* initialize the container */
@@ -1921,8 +1921,8 @@ Datum age_match_two_vle_edges(PG_FUNCTION_ARGS)
 
 /*
  * This function is used when we need to know if the passed in id is at the end
- * of a path. The first arg is the path the second is the vertex id to check and
- * the last is a boolean that syas whether to check the start or the end of the
+ * of a path. The first arg is the path, the second is the vertex id to check and
+ * the last is a boolean that says whether to check the start or the end of the
  * vle path.
  */
 PG_FUNCTION_INFO_V1(age_match_vle_edge_to_id_qual);
@@ -2007,7 +2007,7 @@ Datum age_match_vle_edge_to_id_qual(PG_FUNCTION_ARGS)
     {
         ereport(ERROR,
                 (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-                 errmsg("match_vle_terminal_edge() arguement 1 must be an agtype integer or a graphid")));
+                 errmsg("match_vle_terminal_edge() argument 1 must be an agtype integer or a graphid")));
     }
 
     pos_agt = AG_GET_ARG_AGTYPE_P(2);
@@ -2247,7 +2247,7 @@ Datum age_match_vle_terminal_edge(PG_FUNCTION_ARGS)
     {
         ereport(ERROR,
             (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-             errmsg("match_vle_terminal_edge() arguement 1 must be an agtype integer or a graphid")));
+             errmsg("match_vle_terminal_edge() argument 1 must be an agtype integer or a graphid")));
     }
 
     /* get the veid */
@@ -2277,7 +2277,7 @@ Datum age_match_vle_terminal_edge(PG_FUNCTION_ARGS)
     {
         ereport(ERROR,
             (errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-             errmsg("match_vle_terminal_edge() arguement 2 must be an agtype integer or a graphid")));
+             errmsg("match_vle_terminal_edge() argument 2 must be an agtype integer or a graphid")));
     }
 
     /* compare the path beginning or end points */
@@ -2374,7 +2374,7 @@ Datum age_build_vle_match_edge(PG_FUNCTION_ARGS)
 /*
  * This function checks the edges in a MATCH clause to see if they are unique or
  * not. Filters out all the paths where the edge uniques rules are not met.
- * Arguements can be a combination of agtype ints and VLE_path_containers.
+ * Arguments can be a combination of agtype ints and VLE_path_containers.
  */
 PG_FUNCTION_INFO_V1(_ag_enforce_edge_uniqueness);
 
diff --git a/src/backend/utils/name_validation.c b/src/backend/utils/name_validation.c
index d96f315..2ee998d 100644
--- a/src/backend/utils/name_validation.c
+++ b/src/backend/utils/name_validation.c
@@ -48,7 +48,7 @@ int is_valid_graph_name(const char *graph_name)
  * Returns whether the label name is valid.
  *
  * Note: label_type parameter is not used in this implementation.
- * It should be used if validation algorithm for edge and vetex
+ * It should be used if validation algorithm for edge and vertex
  * differs in future.
  *
  * @param label_name name of the label
diff --git a/src/include/executor/cypher_utils.h b/src/include/executor/cypher_utils.h
index 4d19937..469b729 100644
--- a/src/include/executor/cypher_utils.h
+++ b/src/include/executor/cypher_utils.h
@@ -34,7 +34,7 @@
 
 /*
  * When executing the children of the CREATE, SET, REMOVE, and
- * DELETE clasues, we need to alter the command id in the estate
+ * DELETE clauses, we need to alter the command id in the estate
  * and the snapshot. That way we can hide the modified tuples from
  * the sub clauses that should not know what their parent clauses are
  * doing.
diff --git a/src/include/nodes/cypher_readfuncs.h b/src/include/nodes/cypher_readfuncs.h
index 5d4b0a5..e3bb97a 100644
--- a/src/include/nodes/cypher_readfuncs.h
+++ b/src/include/nodes/cypher_readfuncs.h
@@ -27,7 +27,7 @@
 
 /*
  * Deserialization functions for AGE's ExtensibleNodes. We assign
- * each node to its deserialization functionin the DEFINE_NODE_METHODS
+ * each node to its deserialization function in the DEFINE_NODE_METHODS
  * and DEFINE_NODE_METHODS_EXTENDED macros in ag_nodes.c.
 
  *
diff --git a/src/include/parser/cypher_transform_entity.h b/src/include/parser/cypher_transform_entity.h
index 3c02406..5732c83 100644
--- a/src/include/parser/cypher_transform_entity.h
+++ b/src/include/parser/cypher_transform_entity.h
@@ -53,7 +53,7 @@ typedef struct
 
     /*
      * MATCH clauses are transformed into a select * FROM ... JOIN, etc
-     * We need to know wheter the table that this entity represents is
+     * We need to know whether the table that this entity represents is
      * part of the join tree. If a cypher_node does not meet the conditions
      * set in INCLUDE_NODE_IN_JOIN_TREE. Then we can skip the node when
      * constructing our join tree. The entities around this particular entity
@@ -63,7 +63,7 @@ typedef struct
 
     /*
      * The parse data structure will be transformed into an Expr that represents
-     * the entity. When contructing the join tree, we need to know what it was
+     * the entity. When constructing the join tree, we need to know what it was
      * turned into. If the entity was originally created in a previous clause,
      * this will be a Var that we need to reference to extract the id, startid,
      * endid for the join. If the entity was created in the current clause, then
diff --git a/src/include/utils/load/csv.h b/src/include/utils/load/csv.h
index 8549084..fd1edb4 100644
--- a/src/include/utils/load/csv.h
+++ b/src/include/utils/load/csv.h
@@ -43,7 +43,7 @@ extern "C" {
 #define CSV_STRICT 1    /* enable strict mode */
 #define CSV_REPALL_NL 2 /* report all unquoted carriage returns and linefeeds */
 #define CSV_STRICT_FINI 4 /* causes csv_fini to return CSV_EPARSE if last
-                             field is quoted and doesn't containg ending
+                             field is quoted and doesn't contain ending
                              quote */
 #define CSV_APPEND_NULL 8 /* Ensure that all fields are null-terminated */
 #define CSV_EMPTY_IS_NULL 16 /* Pass null pointer to cb1 function when
@@ -61,7 +61,7 @@ extern "C" {
 struct csv_parser {
     int pstate;         /* Parser state */
     int quoted;         /* Is the current field a quoted field? */
-    size_t spaces;      /* Number of continious spaces after quote or in a non-quoted field */
+    size_t spaces;      /* Number of continuous spaces after quote or in a non-quoted field */
     unsigned char * entry_buf;   /* Entry buffer */
     size_t entry_pos;   /* Current position in entry_buf (and current size of entry) */
     size_t entry_size;  /* Size of entry buffer */
diff --git a/src/include/nodes/cypher_nodes.h b/src/include/nodes/cypher_nodes.h
index 792edde..6680706 100644
--- a/src/include/nodes/cypher_nodes.h
+++ b/src/include/nodes/cypher_nodes.h
@@ -310,7 +310,7 @@ typedef struct cypher_target_node
     /*
      * Attribute number this entity needs to be stored in
      * for parent execution nodes to reference it. If the
      * entity is a varaible (CYPHER_TARGET_NODE_IS_VAR).
      */
     AttrNumber tuple_position;
 } cypher_target_node;
@@ -323,7 +323,7 @@ typedef struct cypher_target_node
  * a variable that was already created AND created in the
  * same clause.
  */
-#define EXISTING_VARAIBLE_DECLARED_SAME_CLAUSE 0x0002
+#define EXISTING_VARIABLE_DECLARED_SAME_CLAUSE 0x0002
 
 //node is the first instance of a declared variable
 #define CYPHER_TARGET_NODE_IS_VAR 0x0004
@@ -346,7 +346,7 @@ typedef struct cypher_target_node
  * later. We don't need to check to see if the vertex still exists.
  */
 #define SAFE_TO_SKIP_EXISTENCE_CHECK(flags) \
-    (flags & EXISTING_VARAIBLE_DECLARED_SAME_CLAUSE)
+    (flags & EXISTING_VARIABLE_DECLARED_SAME_CLAUSE)
 
 #define CYPHER_TARGET_NODE_INSERT_ENTITY(flags) \
     (flags & CYPHER_TARGET_NODE_FLAG_INSERT)
@@ -310,7 +310,7 @@ typedef struct cypher_target_node
      * Attribute number this entity needs to be stored in
      * for parent execution nodes to reference it. If the
-     * entity is a varaible (CYPHER_TARGET_NODE_IS_VAR).
+     * entity is a variable (CYPHER_TARGET_NODE_IS_VAR).
      */
     AttrNumber tuple_position;